.. _Available_themes:    

Available themes
================

Two fully responsive themes are out of the box.


**Classic** based on `Pure CSS <http://purecss.io/>`_ 

.. image:: _static/images/theme_classic.png

**Modern** based on `Bootstrap <http://getbootstrap.com/>`_

.. image:: _static/images/theme_modern.png
 
.. seealso::

   :ref:`How_to_add_a_new_theme` 

